@@ -51,23 +51,57 @@ pub fn get_path_from_artifact(artifact: &str) -> Result<String, Error> {
     let name = name_items.get(1).ok_or_else(|| {
         Error::ParseError(format!("Unable to find name for library {}", &artifact))
     })?;
-    let version_ext = name_items.get(2).ok_or_else(|| {
-        Error::ParseError(format!("Unable to find version for library {}", &artifact))
-    })?.split('@').collect::<Vec<&str>>();
-    let version = version_ext.get(0).ok_or_else(|| {
-        Error::ParseError(format!("Unable to find version for library {}", &artifact))
-    })?;
-    let ext = version_ext.get(1);
 
-    Ok(format!(
-        "{}/{}/{}/{}-{}.{}",
-        package.replace(".", "/"),
-        name,
-        version,
-        name,
-        version,
-        ext.unwrap_or(&"jar")
-    ))
+    if name_items.len() == 3 {
+        let version_ext = name_items
+            .get(2)
+            .ok_or_else(|| {
+                Error::ParseError(format!("Unable to find version for library {}", &artifact))
+            })?
+            .split('@')
+            .collect::<Vec<&str>>();
+        let version = version_ext.get(0).ok_or_else(|| {
+            Error::ParseError(format!("Unable to find version for library {}", &artifact))
+        })?;
+        let ext = version_ext.get(1);
+
+        Ok(format!(
+            "{}/{}/{}/{}-{}.{}",
+            package.replace(".", "/"),
+            name,
+            version,
+            name,
+            version,
+            ext.unwrap_or(&"jar")
+        ))
+    } else {
+        let version = name_items.get(2).ok_or_else(|| {
+            Error::ParseError(format!("Unable to find version for library {}", &artifact))
+        })?;
+
+        let data_ext = name_items
+            .get(3)
+            .ok_or_else(|| {
+                Error::ParseError(format!("Unable to find data for library {}", &artifact))
+            })?
+            .split('@')
+            .collect::<Vec<&str>>();
+        let data = data_ext.get(0).ok_or_else(|| {
+            Error::ParseError(format!("Unable to find data for library {}", &artifact))
+        })?;
+        let ext = data_ext.get(1);
+
+        Ok(format!(
+            "{}/{}/{}/{}-{}-{}.{}",
+            package.replace(".", "/"),
+            name,
+            version,
+            name,
+            version,
+            data,
+            ext.unwrap_or(&"jar")
+        ))
+    }
 }
 
 /// Downloads a file from specified mirrors
